@@ -202,10 +202,11 @@ class ProjectMetadata(Generic[PluginManagerBound]):
                 message = 'The `tool.hatch` configuration must be a table'
                 raise TypeError(message)
 
-            if self._project_file is not None:
-                hatch_file = os.path.join(os.path.dirname(self._project_file), DEFAULT_CONFIG_FILE)
-            else:
-                hatch_file = locate_file(self.root, DEFAULT_CONFIG_FILE) or ''
+            hatch_file = (
+                os.path.join(os.path.dirname(self._project_file), DEFAULT_CONFIG_FILE)
+                if self._project_file is not None
+                else locate_file(self.root, DEFAULT_CONFIG_FILE) or ''
+            )
 
             if hatch_file and os.path.isfile(hatch_file):
                 config = load_toml(hatch_file)
@@ -379,11 +380,8 @@ class CoreMetadata:
             if 'name' in self.dynamic:
                 message = 'Static metadata field `name` cannot be present in field `project.dynamic`'
                 raise ValueError(message)
-            elif 'name' in self.config:
-                raw_name = self.config['name']
-            else:
-                raw_name = ''
 
+            raw_name = self.config.get('name', '')
             if not raw_name:
                 message = 'Missing required field `project.name`'
                 raise ValueError(message)
@@ -624,10 +622,12 @@ class CoreMetadata:
 
     @property
     def python_constraint(self) -> SpecifierSet:
+        from packaging.specifiers import SpecifierSet
+
         if self._python_constraint is None:
             _ = self.requires_python
 
-        return self._python_constraint
+        return cast(SpecifierSet, self._python_constraint)
 
     @property
     def license(self) -> str:  # noqa: A003
@@ -1271,10 +1271,9 @@ class CoreMetadata:
 
                         entries[get_normalized_dependency(requirement)] = requirement
 
-                if self.hatch_metadata.allow_ambiguous_features:
-                    normalized_option = option
-                else:
-                    normalized_option = normalize_project_name(option)
+                normalized_option = (
+                    option if self.hatch_metadata.allow_ambiguous_features else normalize_project_name(option)
+                )
                 if normalized_option in normalized_options:
                     message = (
                         f'Optional dependency groups `{normalized_options[normalized_option]}` and `{option}` of '
